/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2008-2009 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __PACKAGEKIT_H__
#define __PACKAGEKIT_H__

#define __PACKAGEKIT_H_INSIDE__

#include <packagekit-glib2/pk-category.h>
#include <packagekit-glib2/pk-client.h>
#include <packagekit-glib2/pk-client-sync.h>
#include <packagekit-glib2/pk-common.h>
#include <packagekit-glib2/pk-control.h>
#include <packagekit-glib2/pk-control-sync.h>
#include <packagekit-glib2/pk-desktop.h>
#include <packagekit-glib2/pk-details.h>
#include <packagekit-glib2/pk-distro-upgrade.h>
#include <packagekit-glib2/pk-enum.h>
#include <packagekit-glib2/pk-enum-types.h>
#include <packagekit-glib2/pk-error.h>
#include <packagekit-glib2/pk-eula-required.h>
#include <packagekit-glib2/pk-files.h>
#include <packagekit-glib2/pk-media-change-required.h>
#include <packagekit-glib2/pk-item-progress.h>
#include <packagekit-glib2/pk-offline.h>
#include <packagekit-glib2/pk-package-id.h>
#include <packagekit-glib2/pk-package-ids.h>
#include <packagekit-glib2/pk-package-sack.h>
#include <packagekit-glib2/pk-package-sack-sync.h>
#include <packagekit-glib2/pk-progress.h>
#include <packagekit-glib2/pk-repo-detail.h>
#include <packagekit-glib2/pk-repo-signature-required.h>
#include <packagekit-glib2/pk-require-restart.h>
#include <packagekit-glib2/pk-results.h>
#include <packagekit-glib2/pk-task.h>
#include <packagekit-glib2/pk-task-sync.h>
#include <packagekit-glib2/pk-transaction-past.h>
#include <packagekit-glib2/pk-transaction-list.h>
#include <packagekit-glib2/pk-update-detail.h>
#include <packagekit-glib2/pk-version.h>

#ifdef PK_COMPILATION
#include <packagekit-glib2/pk-debug.h>
#endif

#undef __PACKAGEKIT_H_INSIDE__

#endif /* __PACKAGEKIT_H__ */

